@@ -168,7 +168,7 @@ class ApmInstanceDetail(AbstractModel):
         :param CreateUin: 创建人Uin
 注意：此字段可能返回 null，表示取不到有效值。
         :type CreateUin: str
-        :param ServiceCount: 该实例已上报的服务数
+        :param ServiceCount: 该实例已上报的服务端应用数量
 注意：此字段可能返回 null，表示取不到有效值。
         :type ServiceCount: int
         :param CountOfReportSpanPerDay: 日均上报Span数
@@ -218,6 +218,12 @@ class ApmInstanceDetail(AbstractModel):
         :param LogTopicID: 日志主题ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type LogTopicID: str
+        :param ClientCount: 该实例已上报的客户端应用数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClientCount: int
+        :param TotalCount: 该实例已上报的总应用数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TotalCount: int
         """
         self.AmountOfUsedStorage = None
         self.Name = None
@@ -241,6 +247,8 @@ class ApmInstanceDetail(AbstractModel):
         self.LogSource = None
         self.IsRelatedLog = None
         self.LogTopicID = None
+        self.ClientCount = None
+        self.TotalCount = None
 
 
     def _deserialize(self, params):
@@ -271,6 +279,8 @@ class ApmInstanceDetail(AbstractModel):
         self.LogSource = params.get("LogSource")
         self.IsRelatedLog = params.get("IsRelatedLog")
         self.LogTopicID = params.get("LogTopicID")
+        self.ClientCount = params.get("ClientCount")
+        self.TotalCount = params.get("TotalCount")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -552,22 +562,30 @@ class DescribeGeneralMetricDataRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Filters: 要过滤的维度信息，支持：service.name（服务名）、span.kind（客户端/服务端视角）为维度进行过滤。
-
+        :param Filters: 要过滤的维度信息
+service_metric视图支持：service.name（服务名）、span.kind（客户端/服务端视角）为维度进行过滤。
 span.kind:
-
-       server:服务端视角
-       client:客户端视角
-
+	server:服务端视角
+	client:客户端视角
 默认为服务端视角进行查询。
+runtime_metric视图支持：service.name（服务名）维度进行过滤。
+sql_metric视图支持：service.name（服务名）、db.instance（数据库名称）、（db.ip）数据库实例ip维度进行过滤。
+查询sql_duration_avg（耗时）指标时db.instance（数据库名称）必输入。
         :type Filters: list of GeneralFilter
-        :param Metrics: 需要查询的指标，不可自定义输入。支持：service_request_count（总请求）、service_duration（平均响应时间）的指标数据。
+        :param Metrics: 需要查询的指标，不可自定义输入。
+service_metric视图支持：service_request_count（总请求）、service_duration（平均响应时间）、service_error_req_rate（平均错误率）、service_slow_call_count（慢调用）、service_error_request_count（异常数量）。
+runtime_metric视图支持：service_gc_full_count（Full GC）。
+sql_metric视图支持：service_slow_sql_count（慢sql）、sql_duration_avg（耗时）。
         :type Metrics: list of str
         :param InstanceId: 实例ID
         :type InstanceId: str
-        :param ViewName: 视图名称，不可自定义输入。支持：service_metric
+        :param ViewName: 视图名称，不可自定义输入。支持：service_metric、runtime_metric、sql_metric。
         :type ViewName: str
-        :param GroupBy: 聚合维度，支持：service.name（服务名）、span.kind （客户端/服务端视角）维度进行聚合。
+        :param GroupBy: 聚合维度
+service_metric视图支持：service.name（服务名）、span.kind （客户端/服务端视角）维度进行聚合。
+runtime_metric视图支持：service.name（服务名）维度进行聚合。
+sql_metric视图支持：service.name（服务名）、db.statement（sql语句）维度进行聚合。
+查询sql_duration_avg（耗时）指标时service.name（服务名）、db.statement（sql语句）必输入。
         :type GroupBy: list of str
         :param StartTime: 起始时间的时间戳，单位为秒，只支持查询2天内最多1小时的指标数据。
         :type StartTime: int
